@@ -115,7 +115,7 @@
 
 #if defined(__APPLE__) || defined(__apple_build_version__)
   // NOTE: Apple accelerate framework has broken implementations of functions that return a float value,
-  // NOTE: such as sdot(), slange(), clange(), slansy(), clanhe(), slangb()
+  // NOTE: such as sdot(), slange(), clange(), slansy(), clanhe(), slangb(), snrm2(), sasum()
   #undef  ARMA_BLAS_FLOAT_BUG
   #define ARMA_BLAS_FLOAT_BUG
   
@@ -161,13 +161,20 @@
   #undef  ARMA_GCC_VERSION
   #define ARMA_GCC_VERSION (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)
   
-  #if (ARMA_GCC_VERSION < 40803)
-    #error "*** newer compiler required; need gcc 4.8.3 or newer ***"
+  #if (ARMA_GCC_VERSION < 60100)
+    #error "*** newer compiler required; need gcc 6.1 or newer ***"
   #endif
   
-  // #if (ARMA_GCC_VERSION < 60100)
-  //   #pragma message ("WARNING: support for gcc versions older than 6.1 is deprecated")
-  // #endif
+  // gcc 6.1 has proper C++14 support and fixes an OpenMP related bug:
+  // https://gcc.gnu.org/bugzilla/show_bug.cgi?id=57580
+  
+  #if (ARMA_GCC_VERSION < 80100)
+    #pragma message("INFO: support for GCC versions older than 8.1 is deprecated"
+  #endif
+  
+  #if (ARMA_GCC_VERSION >= 170000)
+    #undef ARMA_IGNORE_DEPRECATED_MARKER
+  #endif
   
   #define ARMA_GOOD_COMPILER
   
@@ -226,6 +233,12 @@
   
   // #pragma message ("using Clang extensions")
   
+  #if defined(__clang_major__) && !defined(__apple_build_version__)
+    #if (__clang_major__ >= 24)
+      #undef ARMA_IGNORE_DEPRECATED_MARKER
+    #endif
+  #endif
+  
   #define ARMA_GOOD_COMPILER
   
   #if !defined(__has_attribute)
@@ -300,31 +313,32 @@
     #error "*** newer compiler required ***"
   #endif
   
-  #if (__INTEL_COMPILER < 1500)
+  #if (__INTEL_COMPILER < 1600)
     #error "*** newer compiler required ***"
   #endif
   
   #undef  ARMA_HAVE_GCC_ASSUME_ALIGNED
-  #undef  ARMA_HAVE_ICC_ASSUME_ALIGNED
-  #define ARMA_HAVE_ICC_ASSUME_ALIGNED
   
 #endif
 
 
 #if defined(_MSC_VER)
   
-  #if (_MSC_VER < 1900)
+  #if (_MSC_VER < 1910)
     #error "*** newer compiler required ***"
   #endif
   
   #undef  arma_deprecated
   #define arma_deprecated __declspec(deprecated)
-  // #undef  arma_inline
-  // #define arma_inline __forceinline inline
+  
+  #undef  arma_noinline
+  #define arma_noinline __declspec(noinline)
+  
   
   #pragma warning(push)
   
   #pragma warning(disable: 4127)  // conditional expression is constant
+  #pragma warning(disable: 4146)  // unary minus operator applied to unsigned type, result still unsigned
   #pragma warning(disable: 4180)  // qualifier has no meaning
   #pragma warning(disable: 4244)  // possible loss of data when converting types (see also 4305)
   #pragma warning(disable: 4510)  // default constructor could not be generated
@@ -344,8 +358,6 @@
   #pragma warning(disable: 4714)  // __forceinline can't be inlined
   #pragma warning(disable: 4800)  // value forced to bool
   
-  // NOTE: also possible to disable 4146 (unary minus operator applied to unsigned type, result still unsigned)
-  
   #if defined(ARMA_HAVE_CXX17)
   #pragma warning(disable: 26812)  // unscoped enum
   #pragma warning(disable: 26819)  // unannotated fallthrough
@@ -376,18 +388,6 @@
 #endif
 
 
-#if defined(__SUNPRO_CC)
-  
-  // http://www.oracle.com/technetwork/server-storage/solarisstudio/training/index-jsp-141991.html
-  // http://www.oracle.com/technetwork/server-storage/solarisstudio/documentation/cplusplus-faq-355066.html
-  
-  #if (__SUNPRO_CC < 0x5140)
-    #error "*** newer compiler required ***"
-  #endif
-  
-#endif
-
-
 #if defined(ARMA_HAVE_CXX14)
   #undef  arma_deprecated
   #define arma_deprecated [[deprecated]]
@@ -430,17 +430,6 @@
 #endif
 
 
-#if defined(ARMA_USE_OPENMP)
-  #if (defined(ARMA_GCC_VERSION) && (ARMA_GCC_VERSION < 50400))
-    // due to https://gcc.gnu.org/bugzilla/show_bug.cgi?id=57580
-    #undef ARMA_USE_OPENMP
-    #if !defined(ARMA_DONT_PRINT_OPENMP_WARNING)
-      #pragma message ("WARNING: use of OpenMP disabled due to compiler bug in gcc <= 5.3")
-    #endif
-  #endif
-#endif
-
-
 #if (defined(__FAST_MATH__) || (defined(__FINITE_MATH_ONLY__) && (__FINITE_MATH_ONLY__ > 0)) || defined(_M_FP_FAST))
   #undef  ARMA_FAST_MATH
   #define ARMA_FAST_MATH
@@ -498,11 +487,10 @@
 #undef major
 
 
-// optionally allow disabling of compile-time deprecation messages (not recommended)
-// NOTE: option 'ARMA_IGNORE_DEPRECATED_MARKER' will be removed
-// NOTE: disabling deprecation messages is counter-productive
+// WARNING: option 'ARMA_IGNORE_DEPRECATED_MARKER' is not supported when compiling with gcc 17+ or clang 24+
+// WARNING: disabling deprecation messages is counter-productive
 
-#if defined(ARMA_IGNORE_DEPRECATED_MARKER) && (!defined(ARMA_DONT_IGNORE_DEPRECATED_MARKER)) && (!defined(ARMA_EXTRA_DEBUG))
+#if defined(ARMA_IGNORE_DEPRECATED_MARKER)
   #undef  arma_deprecated
   #define arma_deprecated
 
