@@ -258,69 +258,79 @@ accu(const T1& X)
   {
   arma_debug_sigprint();
   
-  const Proxy<T1> P(X);
-  
-  if(is_Mat<typename Proxy<T1>::stored_type>::value || is_subview_col<typename Proxy<T1>::stored_type>::value)
+  if((is_Mat<T1>::value) || (is_subview_col<T1>::value) || (is_Mat<typename Proxy<T1>::stored_type>::value))
     {
-    const quasi_unwrap<typename Proxy<T1>::stored_type> tmp(P.Q);
+    const quasi_unwrap<T1> U(X);
     
-    return arrayops::accumulate(tmp.M.memptr(), tmp.M.n_elem);
+    return arrayops::accumulate(U.M.memptr(), U.M.n_elem);
     }
   
+  const Proxy<T1> P(X);
+  
   return (Proxy<T1>::use_at) ? accu_proxy_at(P) : accu_proxy_linear(P);
   }
 
 
 
-//! explicit handling of dot product expressed as matrix multiplication
-template<typename T1, typename T2>
+template<typename T1>
 arma_warn_unused
 inline
 typename T1::elem_type
-accu(const Glue<T1,T2,glue_times>& expr)
+accu(const eOp<T1,eop_square>& expr)
   {
   arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
-  if( (is_cx<eT>::no) && (resolves_to_rowvector<T1>::value && resolves_to_colvector<T2>::value) )
+  typedef eOp<T1,eop_square> expr_type;
+  
+  typedef typename expr_type::proxy_type::stored_type expr_P_stored_type;
+  
+  if((is_Mat<expr_P_stored_type>::value) || (is_subview_col<expr_P_stored_type>::value))
     {
-    arma_debug_print("accu(): dot product optimisation");
+    const quasi_unwrap<expr_P_stored_type> U(expr.P.Q);
     
-    constexpr bool proxy_is_mat = (is_Mat<typename Proxy<T1>::stored_type>::value && is_Mat<typename Proxy<T2>::stored_type>::value);
+    const eT* X_mem = U.M.memptr();
     
-    constexpr bool use_at = (Proxy<T1>::use_at) || (Proxy<T2>::use_at);
-    
-    constexpr bool fast_unwrap = (partial_unwrap<T1>::is_fast && partial_unwrap<T2>::is_fast);
-    
-    if(proxy_is_mat || use_at || fast_unwrap)
-      {
-      const partial_unwrap<T1> UA(expr.A);
-      const partial_unwrap<T2> UB(expr.B);
-      
-      const typename partial_unwrap<T1>::stored_type& A = UA.M;
-      const typename partial_unwrap<T2>::stored_type& B = UB.M;
-      
-      arma_conform_assert_mul_size(A, B, UA.do_trans, UB.do_trans, "matrix multiplication");
-      
-      const eT val = op_dot::direct_dot(A.n_elem, A.memptr(), B.memptr());
-      
-      return (UA.do_times || UB.do_times) ? (val * UA.get_val() * UB.get_val()) : val;
-      }
-    else
-      {
-      const Proxy<T1> PA(expr.A);
-      const Proxy<T2> PB(expr.B);
-      
-      arma_conform_assert_mul_size(PA.get_n_rows(), PA.get_n_cols(), PB.get_n_rows(), PB.get_n_cols(), "matrix multiplication");
-      
-      return op_dot::apply_proxy_linear(PA,PB);
-      }
+    return op_dot::direct_dot(U.M.n_elem, X_mem, X_mem);
     }
   
-  const Mat<eT> tmp(expr);
+  const Proxy<expr_type> P(expr);
   
-  return arrayops::accumulate( tmp.memptr(), tmp.n_elem );
+  return (Proxy<expr_type>::use_at) ? accu_proxy_at(P) : accu_proxy_linear(P);
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+inline
+typename T1::elem_type
+accu(const eOp<T1,eop_pow>& expr)
+  {
+  arma_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  
+  typedef eOp<T1,eop_pow> expr_type;
+  
+  if(expr.aux == eT(2))
+    {
+    typedef eOp<T1,eop_square> modified_expr_type;
+    
+    return accu( reinterpret_cast< const modified_expr_type& >(expr) );
+    }
+  
+  if((expr.aux == eT(0.5)) && is_non_integral<eT>::value)
+    {
+    typedef eOp<T1,eop_sqrt> modified_expr_type;
+    
+    return accu( reinterpret_cast< const modified_expr_type& >(expr) );
+    }
+  
+  const Proxy<expr_type> P(expr);
+  
+  return (Proxy<expr_type>::use_at) ? accu_proxy_at(P) : accu_proxy_linear(P);
   }
 
 
@@ -889,20 +899,83 @@ accu(const BaseCube<typename T1::elem_type,T1>& X)
   {
   arma_debug_sigprint();
   
-  const ProxyCube<T1> P(X.get_ref());
-  
-  if(is_Cube<typename ProxyCube<T1>::stored_type>::value)
+  if((is_Cube<T1>::value) || (is_Cube<typename ProxyCube<T1>::stored_type>::value))
     {
-    unwrap_cube<typename ProxyCube<T1>::stored_type> tmp(P.Q);
+    const unwrap_cube<T1> U(X.get_ref());
     
-    return arrayops::accumulate(tmp.M.memptr(), tmp.M.n_elem);
+    return arrayops::accumulate(U.M.memptr(), U.M.n_elem);
     }
   
+  const ProxyCube<T1> P(X.get_ref());
+  
   return (ProxyCube<T1>::use_at) ? accu_cube_proxy_at(P) : accu_cube_proxy_linear(P);
   }
 
 
 
+template<typename T1>
+arma_warn_unused
+inline
+typename T1::elem_type
+accu(const eOpCube<T1,eop_square>& expr)
+  {
+  arma_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  
+  typedef eOpCube<T1,eop_square> expr_type;
+  
+  typedef typename expr_type::proxy_type::stored_type expr_P_stored_type;
+  
+  if(is_Cube<expr_P_stored_type>::value)
+    {
+    const unwrap_cube<expr_P_stored_type> U(expr.P.Q);
+    
+    const eT* X_mem = U.M.memptr();
+    
+    return op_dot::direct_dot(U.M.n_elem, X_mem, X_mem);
+    }
+  
+  const ProxyCube<expr_type> P(expr);
+  
+  return (ProxyCube<expr_type>::use_at) ? accu_cube_proxy_at(P) : accu_cube_proxy_linear(P);
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+inline
+typename T1::elem_type
+accu(const eOpCube<T1,eop_pow>& expr)
+  {
+  arma_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  
+  typedef eOpCube<T1,eop_pow> expr_type;
+  
+  if(expr.aux == eT(2))
+    {
+    typedef eOpCube<T1,eop_square> modified_expr_type;
+    
+    return accu( reinterpret_cast< const modified_expr_type& >(expr) );
+    }
+  
+  if((expr.aux == eT(0.5)) && is_non_integral<eT>::value)
+    {
+    typedef eOpCube<T1,eop_sqrt> modified_expr_type;
+    
+    return accu( reinterpret_cast< const modified_expr_type& >(expr) );
+    }
+  
+  const ProxyCube<expr_type> P(expr);
+  
+  return (ProxyCube<expr_type>::use_at) ? accu_cube_proxy_at(P) : accu_cube_proxy_linear(P);
+  }
+
+
+
 //! explicit handling of multiply-and-accumulate (cube version)
 template<typename T1, typename T2>
 arma_warn_unused
@@ -914,8 +987,8 @@ accu(const eGlueCube<T1,T2,eglue_schur>& expr)
   
   typedef eGlueCube<T1,T2,eglue_schur> expr_type;
   
-  typedef typename ProxyCube<T1>::stored_type P1_stored_type;
-  typedef typename ProxyCube<T2>::stored_type P2_stored_type;
+  typedef typename expr_type::proxy1_type::stored_type P1_stored_type;
+  typedef typename expr_type::proxy2_type::stored_type P2_stored_type;
   
   if(is_Cube<P1_stored_type>::value && is_Cube<P2_stored_type>::value)
     {
@@ -1046,6 +1119,24 @@ accu(const SpGlue<T1,T2,spglue_schur>& expr)
   const SpProxy<T1> px(expr.A);
   const SpProxy<T2> py(expr.B);
   
+  arma_conform_assert_same_size(px.get_n_rows(), px.get_n_cols(), py.get_n_rows(), py.get_n_cols(), "element-wise multiplication");
+  
+  if( (px.get_n_nonzero() == 0) && (py.get_n_nonzero() == 0) )  { return eT(0); }
+  
+  typedef typename SpProxy<T1>::stored_type px_Q_type;
+  typedef typename SpProxy<T2>::stored_type py_Q_type;
+  
+  if(is_SpMat<px_Q_type>::value && is_SpMat<py_Q_type>::value)
+    {
+    const unwrap_spmat<px_Q_type> UX(px.Q);
+    const unwrap_spmat<py_Q_type> UY(py.Q);
+    
+    const SpMat<eT>& X = UX.M;
+    const SpMat<eT>& Y = UY.M;
+    
+    if(&X == &Y)  { return op_dot::direct_dot(X.n_nonzero, X.values, X.values); }
+    }
+  
   typename SpProxy<T1>::const_iterator_type x_it     = px.begin();
   typename SpProxy<T1>::const_iterator_type x_it_end = px.end();
   
@@ -1073,10 +1164,14 @@ accu(const SpGlue<T1,T2,spglue_schur>& expr)
       
       if((x_it_col < y_it_col) || ((x_it_col == y_it_col) && (x_it_row < y_it_row))) // if y is closer to the end
         {
+        acc += (*x_it) * eT(0);  // in case (*x_it) is inf or nan
+        
         ++x_it;
         }
       else // x is closer to the end
         {
+        acc += eT(0) * (*y_it);  // in case (*y_it) is inf or nan
+        
         ++y_it;
         }
       }
@@ -1104,6 +1199,30 @@ accu(const SpOp<T1, spop_type>& expr)
   
   if(is_vectorise)  { return accu(expr.m); }
   
+  if(is_same_type<spop_type, spop_square>::yes)
+    {
+    const SpProxy<T1> P(expr.m);
+    
+    const uword N = P.get_n_nonzero();
+    
+    if(N == 0)  { return eT(0); }
+    
+    if(SpProxy<T1>::use_iterator == false)
+      {
+      return op_dot::direct_dot(N, P.get_values(), P.get_values());
+      }
+    else
+      {
+      typename SpProxy<T1>::const_iterator_type it = P.begin();
+      
+      eT val = eT(0);
+      
+      for(uword i=0; i < N; ++i)  { const eT tmp = (*it); val += (tmp*tmp); ++it; }
+      
+      return val;
+      }
+    }
+  
   const SpMat<eT> tmp = expr;
   
   return accu(tmp);
