@@ -147,50 +147,10 @@ logspace(const double A, const double B, const uword N = 50u)
 
 
 
-//
-// log_exp_add
-
-template<typename eT>
-arma_warn_unused
-inline
-typename arma_real_only<eT>::result
-log_add_exp(eT log_a, eT log_b)
-  {
-  if(log_a < log_b)
-    {
-    std::swap(log_a, log_b);
-    }
-  
-  const eT negdelta = log_b - log_a;
-  
-  if( (negdelta < Datum<eT>::log_min) || (arma_isfinite(negdelta) == false) )
-    {
-    return log_a;
-    }
-  else
-    {
-    return (log_a + std::log1p(std::exp(negdelta)));
-    }
-  }
-
-
-
-// for compatibility with earlier versions
-template<typename eT>
-arma_warn_unused
-inline
-typename arma_real_only<eT>::result
-log_add(eT log_a, eT log_b)
-  {
-  return log_add_exp(log_a, log_b);
-  }
-  
-
-
 //! kept for compatibility with old user code
 template<typename eT>
-arma_warn_unused
-arma_inline
+arma_frown("change arma::is_finite(val) to std::isfinite(val)")
+inline
 bool
 is_finite(const eT x, const typename arma_scalar_only<eT>::result* junk = nullptr)
   {
@@ -203,7 +163,7 @@ is_finite(const eT x, const typename arma_scalar_only<eT>::result* junk = nullpt
 
 //! kept for compatibility with old user code
 template<typename T1>
-arma_warn_unused
+arma_frown("change arma::is_finite(X) to X.is_finite()")
 inline
 bool
 is_finite(const Base<typename T1::elem_type,T1>& X)
@@ -217,7 +177,7 @@ is_finite(const Base<typename T1::elem_type,T1>& X)
 
 //! kept for compatibility with old user code
 template<typename T1>
-arma_warn_unused
+arma_frown("change arma::is_finite(X) to X.is_finite()")
 inline
 bool
 is_finite(const SpBase<typename T1::elem_type,T1>& X)
@@ -231,7 +191,7 @@ is_finite(const SpBase<typename T1::elem_type,T1>& X)
 
 //! kept for compatibility with old user code
 template<typename T1>
-arma_warn_unused
+arma_frown("change arma::is_finite(X) to X.is_finite()")
 inline
 bool
 is_finite(const BaseCube<typename T1::elem_type,T1>& X)
@@ -584,4 +544,54 @@ affmul(const T1& A, const T2& B)
 
 
 
+namespace priv
+  {
+  // internal use only
+  template<typename eT>
+  arma_warn_unused
+  inline
+  typename arma_real_only<eT>::result
+  internal_log_add_exp(eT log_a, eT log_b)
+    {
+    if(log_a < log_b)  { std::swap(log_a, log_b); }
+    
+    const eT negdelta = log_b - log_a;
+    
+    if( (negdelta < Datum<eT>::log_min) || (arma_isfinite(negdelta) == false) )
+      {
+      return log_a;
+      }
+    else
+      {
+      return (log_a + std::log1p(std::exp(negdelta)));
+      }
+    }
+  }
+
+
+
+// DO NOT USE; kept only for compatibility with old user code
+template<typename eT>
+arma_deprecated
+inline
+typename arma_real_only<eT>::result
+log_add_exp(eT log_a, eT log_b)
+  {
+  return priv::internal_log_add_exp(log_a, log_b);
+  }
+
+
+
+// DO NOT USE; kept only for compatibility with old user code
+template<typename eT>
+arma_deprecated
+inline
+typename arma_real_only<eT>::result
+log_add(eT log_a, eT log_b)
+  {
+  return priv::internal_log_add_exp(log_a, log_b);
+  }
+
+
+
 //! @}
