@@ -1,11 +1,19 @@
-// Copyright (C) 2012-2015 National ICT Australia (NICTA)
+// SPDX-License-Identifier: Apache-2.0
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
+// 
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup subview_each
@@ -20,37 +28,35 @@ class subview_each_common
   
   typedef typename parent::elem_type eT;
   
-  const parent& p;
+  const parent& P;
   
-  inline void check_size(const Mat<typename parent::elem_type>& A) const;
+  template<typename eT2>
+  inline void check_size(const Mat<eT2>& A) const;
   
   
   protected:
   
-  arma_inline subview_each_common(const parent& in_p);
+  arma_inline subview_each_common(const parent& in_P);
+       inline subview_each_common() = delete;
   
   arma_inline const Mat<typename parent::elem_type>& get_mat_ref_helper(const Mat    <typename parent::elem_type>& X) const;
   arma_inline const Mat<typename parent::elem_type>& get_mat_ref_helper(const subview<typename parent::elem_type>& X) const;
   
   arma_inline const Mat<typename parent::elem_type>& get_mat_ref() const;
   
-  arma_cold inline const std::string incompat_size_string(const Mat<typename parent::elem_type>& A) const;
-  
-  
-  private:
-  
-  subview_each_common();
+  template<typename eT2>
+  arma_cold inline const std::string incompat_size_string(const Mat<eT2>& A) const;
   };
 
 
 
-
+// NOTE: deliberately not derived from Base
 template<typename parent, unsigned int mode>
 class subview_each1 : public subview_each_common<parent, mode>
   {
   protected:
   
-  arma_inline subview_each1(const parent& in_p);
+  arma_inline subview_each1(const parent& in_P);
   
   
   public:
@@ -58,6 +64,7 @@ class subview_each1 : public subview_each_common<parent, mode>
   typedef typename parent::elem_type eT;
   
   inline ~subview_each1();
+  inline  subview_each1() = delete;
   
   // deliberately returning void
   template<typename T1> inline void operator=  (const Base<eT,T1>& x);
@@ -67,20 +74,19 @@ class subview_each1 : public subview_each_common<parent, mode>
   template<typename T1> inline void operator/= (const Base<eT,T1>& x);
   
   
-  private:
-  
   friend class Mat<eT>;
   friend class subview<eT>;
   };
 
 
 
+// NOTE: deliberately not derived from Base
 template<typename parent, unsigned int mode, typename TB>
 class subview_each2 : public subview_each_common<parent, mode>
   {
   protected:
   
-  inline subview_each2(const parent& in_p, const Base<uword, TB>& in_indices);
+  inline subview_each2(const parent& in_P, const Base<uword, TB>& in_indices);
   
   
   public:
@@ -90,7 +96,9 @@ class subview_each2 : public subview_each_common<parent, mode>
   typedef typename parent::elem_type eT;
   
   inline void check_indices(const Mat<uword>& indices) const;
+  
   inline ~subview_each2();
+  inline  subview_each2() = delete;
   
   // deliberately returning void
   template<typename T1> inline void operator=  (const Base<eT,T1>& x);
@@ -100,8 +108,6 @@ class subview_each2 : public subview_each_common<parent, mode>
   template<typename T1> inline void operator/= (const Base<eT,T1>& x);
   
   
-  private:
-  
   friend class Mat<eT>;
   friend class subview<eT>;
   };
@@ -114,7 +120,7 @@ class subview_each1_aux
   
   template<typename parent, unsigned int mode, typename T2>
   static inline Mat<typename parent::elem_type> operator_plus(const subview_each1<parent,mode>& X, const Base<typename parent::elem_type,T2>& Y);
-    
+  
   template<typename parent, unsigned int mode, typename T2>
   static inline Mat<typename parent::elem_type> operator_minus(const subview_each1<parent,mode>& X, const Base<typename parent::elem_type,T2>& Y);
   
@@ -139,7 +145,7 @@ class subview_each2_aux
   
   template<typename parent, unsigned int mode, typename TB, typename T2>
   static inline Mat<typename parent::elem_type> operator_plus(const subview_each2<parent,mode,TB>& X, const Base<typename parent::elem_type,T2>& Y);
-    
+  
   template<typename parent, unsigned int mode, typename TB, typename T2>
   static inline Mat<typename parent::elem_type> operator_minus(const subview_each2<parent,mode,TB>& X, const Base<typename parent::elem_type,T2>& Y);
   
